==============================
``psyclone.tests.errors_test``
==============================

.. automodule:: psyclone.tests.errors_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.errors_test
